@@ -5,11 +5,12 @@ set -ex
 cd $DIR/..
 
 if [ ! -d "libmdbx" ] ; then
-git clone git@github.com:erthink/libmdbx.git
+git clone git@github.com:rmw-lib/libmdbx.git
 cd libmdbx
+git pull git@github.com:erthink/libmdbx.git
 else
 cd libmdbx
-git pull
+git pull git@github.com:erthink/libmdbx.git
 fi
 
 make dist
